/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Pool.java 5512 2010-05-27 15:14:57Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.pool.annotation;

import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;
import static org.ow2.util.pool.api.IPoolConfiguration.DEFAULT_MAX;
import static org.ow2.util.pool.api.IPoolConfiguration.DEFAULT_MAX_WAITERS;
import static org.ow2.util.pool.api.IPoolConfiguration.DEFAULT_MIN;
import static org.ow2.util.pool.api.IPoolConfiguration.DEFAULT_SPARE;
import static org.ow2.util.pool.api.IPoolConfiguration.DEFAULT_TIMEOUT;

import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
 * Allow to specify pool attributes.
 * @author Florent BENOIT
 */
@Target(TYPE)
@Retention(RUNTIME)
public @interface Pool {

    /**
     * Maximum size of the pool (default is unlimited).
     */
    int max() default DEFAULT_MAX;

    /**
     * Minimum size of the pool (default is 0).
     */
    int min() default DEFAULT_MIN;

    /**
     * Spare size of the pool (default is 15).
     */
    int spare() default DEFAULT_SPARE;

    /**
     * Timeout (default is 10s = 10000L).
     */
    long timeout() default DEFAULT_TIMEOUT;

    /**
     * Number of waiters that can wait if the pool has reached its maximum value (default is 1000).
     */
    int maxWaiters() default DEFAULT_MAX_WAITERS;
}
